#coding:utf-8

from setuptools import setup, find_packages 

setup(
    name='ftwo',
    version="0.1", 
    description="Some common use functions", 
    author="Lerry",
    author_email="lvdachao@gmail.com",
    packages = ['ftwo'],
    zip_safe=False,
    include_package_data=True,
    install_requires = [
    ],
    url = "https://bitbucket.org/lerry/42",
)

